@@ -1,4 +1,6 @@
-from . import control
+from gsmo import control
+from .modules import Modules
+from .papermill import execute
 
 def OK(msg, throw=True):
     exc = control.OK(msg)
